@@ -365,6 +365,62 @@ def entityFilerCategoryEN(arg: str) -> str:
     raise TransformationException(f'Unknown filer category "{arg}"')
 
 
+# Inline XBRL Part 1: Specification 1.0 Transformation Rules (Sec. 14)
+# From http://www.xbrl.org/Specification/inlineXBRL-part1/PR-2010-02-10/inlineXBRL-part1-PR-2010-02-10.html
+ixt = {
+    'datedoteu': dateDayMonthYear,
+    'datedotus': dateMonthDayYear,
+    'datelonguk': dateDayMonthYearEN,
+    'datelongus': dateMonthDayYearEN,
+    'dateshortuk': dateDayMonthYearEN,
+    'dateshortus': dateMonthDayYearEN,
+    'dateslasheu': dateDayMonthYear,
+    'dateslashus': dateMonthDayYear,
+    'datelongdaymonthuk': dateDayMonthEN,
+    'datelongmonthdayus': dateMonthDayEN,
+    'dateshortdaymonthuk': dateDayMonthEN,
+    'dateshortmonthdayus': dateMonthDayEN,
+    'dateslashdaymontheu': dateDayMonth,
+    'dateslashmonthdayus': dateMonthDay,
+    'datelongyearmonth': dateYearMonthEN,
+    'dateshortyearmonth': dateYearMonthEN,
+    'datelongmonthyear': dateMonthYearEN,
+    'dateshortmonthyear': dateMonthYearEN,
+    'numcomma': numCommaDecimal, #  I think this is right? 
+    'numcommadot': numDotDecimal,
+    'numdash': lambda arg: '0',
+    'numdotcomma': numCommaDecimal,
+    'numspacecomma': numCommaDecimal,
+    'numspacedot': numDotDecimal
+}
+
+# XII Transformation Registry 2
+# From http://www.xbrl.org/specification/inlinexbrl-transformationregistry/rec-2011-07-31/inlinexbrl-transformationregistry-rec-2011-07-31.html
+
+ixt2 = {
+    'booleanfalse': lambda arg: 'false',
+    'booleantrue': lambda arg: 'true',
+    'datedaymonth': dateDayMonth,
+    'datedaymonthen': dateDayMonthEN,
+    'datedaymonthyear': dateDayMonthYear,
+    'datedaymonthyearen': dateDayMonthYearEN,
+    'dateerayearmonthdayjp': notImplemented,
+    'dateerayearmonthjp': notImplemented,
+    'datemonthday': dateMonthDay,
+    'datemonthdayen': dateMonthDayEN,
+    'datemonthdayyear': dateMonthDayYear,
+    'datemonthdayyearen': dateMonthDayYearEN,
+    'datemonthyearen': dateMonthYearEN,
+    'dateyearmonthdaycjk': notImplemented,
+    'dateyearmonthen': dateYearMonthEN,
+    'dateyearmonthcjk': notImplemented,
+    'nocontent': lambda arg: '',
+    'numcommadecimal': numCommaDecimal,
+    'numdotdecimal': numDotDecimal,
+    'numunitdecimal': notImplemented,
+    'zerodash': lambda arg: '0'
+}
+
 # endregion ixt-sec mappings
 
 ixt3 = {
@@ -521,7 +577,11 @@ def normalize(namespace: str, formatCode: str, value: str) -> str:
     value = value.strip().lower()
 
     try:
-        if namespace == 'http://www.xbrl.org/inlineXBRL/transformation/2015-02-26':
+        if namespace == 'http://www.xbrl.org/inlineXBRL/transformation/2010-04-20':
+            return ixt[formatCode](value)
+        elif namespace == 'http://www.xbrl.org/inlineXBRL/transformation/2011-07-31':
+            return ixt2[formatCode](value)
+        elif namespace == 'http://www.xbrl.org/inlineXBRL/transformation/2015-02-26':
             return ixt3[formatCode](value)
         elif namespace == 'http://www.xbrl.org/inlineXBRL/transformation/2020-02-12':
             return ixt4[formatCode](value)
